@@ -30,7 +30,7 @@ def location_dec(str):
 def xiami_download_lyric(lrc_url, file_name, output_dir):
     lrc = get_html(lrc_url, faker = True)
     if len(lrc) > 0:
-        with open(output_dir + "/" + file_name.replace('/', '-') + '.lrc', 'w') as x:
+        with open(output_dir + "/" + file_name.replace('/', '-') + '.lrc', 'w', encoding='utf-8') as x:
             x.write(lrc)
 
 def xiami_download_song(sid, output_dir = '.', merge = True, info_only = False):
@@ -43,6 +43,8 @@ def xiami_download_song(sid, output_dir = '.', merge = True, info_only = False):
     url = location_dec(i.getElementsByTagName("location")[0].firstChild.nodeValue)
     lrc_url = i.getElementsByTagName("lyric")[0].firstChild.nodeValue
     type, ext, size = url_info(url, faker = True)
+    if not ext:
+        ext = 'mp3'
     
     print_info(site_info, song_title, type, size)
     if not info_only:
@@ -66,6 +68,8 @@ def xiami_download_showcollect(cid, output_dir = '.', merge = True, info_only =
         url = location_dec(i.getElementsByTagName("location")[0].firstChild.nodeValue)
         lrc_url = i.getElementsByTagName("lyric")[0].firstChild.nodeValue
         type, ext, size = url_info(url, faker = True)
+        if not ext:
+            ext = 'mp3'
         
         print_info(site_info, song_title, type, size)
         if not info_only:
@@ -88,7 +92,9 @@ def xiami_download_album(aid, output_dir = '.', merge = True, info_only = False)
         url = location_dec(i.getElementsByTagName("location")[0].firstChild.nodeValue)
         lrc_url = i.getElementsByTagName("lyric")[0].firstChild.nodeValue
         type, ext, size = url_info(url, faker = True)
-        
+        if not ext:
+            ext = 'mp3'
+
         print_info(site_info, song_title, type, size)
         if not info_only:
             file_name = "%02d.%s" % (track_nr, song_title)
